Migration from Zope 4 to Zope 5.0
=================================

Prerequisites
-------------

* Update your project to run on the latest version of Zope 4.
* Update your project to run on Python 3.8+.
* Make sure no deprecation warnings are emitted when running your tests and
  when running the Zope instance

Migration
---------

* Switch to use Zope 5.0 by using its dependencies for your project.
* No additional steps should be necessary if the prerequisites are fulfilled.
